@@ -12,6 +12,8 @@ from puke.Console import *
 from puke.FileSystem import *
 from puke.Env import *
 from puke.Cache import *
+from puke.Require import *
+from puke.Yak import *
 
 VERSION = 0.1
 
@@ -95,7 +97,6 @@ def run():
         else:
             raise PukeError("No generate file found!")
     
-
     retval = execfile(script)
 
     #
